@@ -7,6 +7,7 @@ from sidechainnet.dataloaders.SCNDataset import SCNDataset
 import requests
 import tqdm
 
+import sidechainnet as scn
 from sidechainnet.create import format_sidechainnet_path
 from sidechainnet.dataloaders.collate import prepare_dataloaders
 
@@ -261,6 +262,10 @@ def load(casp_version=12,
         local_path = _download_sidechainnet(casp_version, thinning, scn_dir)
 
     scn_dict = _load_dict(local_path)
+
+    # Patch for removing 1GJJ_1_A, see Issue #38
+    scn_dict = scn.utils.manual_adjustment._repair_1GJJ_1_A(scn_dict)
+
     scn_dict = filter_dictionary_by_resolution(scn_dict, threshold=filter_by_resolution)
     if complete_structures_only:
         scn_dict = filter_dictionary_by_missing_residues(scn_dict)
